@@ -619,7 +619,8 @@ storage of variables templates")%location)
             for nameVar in dictVars:
                 if not "__" in nameVar and (not\
                     (getattr(dataVar,nameVar).has_key("hide") and\
-                     getattr(dataVar,nameVar)['hide']) or verbose>1):
+                     getattr(dataVar,nameVar)['hide']) or verbose>1 \
+                     or varsFilter):
                     if varsNames and not nameVar in varsNames:
                         continue
                     if reFilter and not reFilter.search(nameVar):
