@@ -274,13 +274,14 @@ class opt(optparse.OptionParser):
                 )
     """
 
-    variable_control = \
+    variable_set = \
         [{'longOption':"set",
          'optVal':"VAR=VALUE",
          'action':'append',
          'help':_("set value for variable")
-        },
-        {'shortOption':"v",
+        }]
+    variable_view = \
+        [{'shortOption':"v",
          'longOption':"vars",
          'action':'count',
          'help':_("print variables, if the two options is verbose "
@@ -295,6 +296,7 @@ is used in conjunction with the options '-v --vars'")
          'help':_("output variables in the format of XML, \
 is used in conjunction with the option '-v --vars'")
         }]
+    variable_control = variable_set + variable_view
 
     color_control = \
         [
