@@ -232,6 +232,7 @@ class varsShare:
                      "CDS":"Calculate Directory Server",
                      "CLS":"Calculate Linux Scratch",
                      "CSS":"Calculate Scratch Server",
+                     "CMC":"Calculate Media Center",
                      "Gentoo":"Gentoo"}
 
     dictLinuxSubName = {"CLD":"KDE", "CLDX":"XFCE", "CLDG":"GNOME"}
@@ -241,6 +242,7 @@ class varsShare:
                       'CLDG':'desktop',
                       'CLDX':'desktop',
                       'CLS':'desktop',
+                      'CMC':'desktop',
                       'CSS':'server'}
 
     # data object from LDAP
